@@ -1,11 +1,9 @@
 package CAPDBICTest::CGIApp;
-our $VERSION = '0.100210';
 use strict;
 use warnings;
 
 use parent 'CGI::Application';
 
-use CGI::Application::Plugin::DBH (qw/dbh_config dbh/);
 use CAPDBICTest::Schema;
 use CGI::Application::Plugin::DBIx::Class ':all';
 
@@ -15,10 +13,9 @@ our $CONNECT_STR = "dbi:SQLite:dbname=$DBFILE";
 sub cgiapp_init {
   my $self = shift;
 
-  $self->dbh_config( $CONNECT_STR );
-
   $self->dbic_config({
      schema => 'CAPDBICTest::Schema',
+     connect_info => "dbi:SQLite:dbname=$DBFILE",
   });
 }
 
